@@ -4,6 +4,7 @@ use strict;
 use warnings;
 use Sisimai::RFC5322;
 
+use constant INDICATORS => { 'deliverystatus' => (1 << 1), 'message-rfc822' => (1 << 2) };
 sub DELIVERYSTATUS {
     # Data structure for decoded bounce messages
     # @private
@@ -23,16 +24,7 @@ sub DELIVERYSTATUS {
         'diagnosis'    => '',   # The value of Diagnostic-Code header
         'recipient'    => '',   # The value of Final-Recipient header
         'feedbacktype' => '',   # Feedback Type
-    };
-}
-sub INDICATORS {
-    # Flags for position variables
-    # @private
-    # @return   [Hash] Position flag data
-    # @since    v4.13.0
-    return {
-        'deliverystatus' => (1 << 1),
-        'message-rfc822' => (1 << 2),
+        'toxic'        => 0,    # EXPERIMENTAL
     };
 }
 sub description { return '' }
@@ -40,10 +32,10 @@ sub index {
     # Alphabetical sorted MTA module list
     # @return   [Array] MTA list with order
     return [qw|
-        Activehunter AmazonSES ApacheJames Biglobe Courier Domino DragonFly EZweb
-        EinsUndEins Exchange2003 Exchange2007 Exim FML GMX GoogleGroups GoogleWorkspace Gmail
-        IMailServer InterScanMSS KDDI MailFoundry MailMarshalSMTP MessagingServer Notes
-        OpenSMTPD Postfix Sendmail V5sendmail Verizon X1 X2 X3 X6 Zoho mFILTER qmail
+        Activehunter AmazonSES ApacheJames Biglobe Courier Domino DragonFly EZweb EinsUndEins Exchange2003
+        Exchange2007 Exim FML GMX GoogleGroups GoogleWorkspace Gmail IMailServer KDDI MailFoundry Mimecast
+        MailMarshal MessagingServer Notes OpenSMTPD Postfix Sendmail TrendMicro V5sendmail Verizon
+        X1 X2 X3 X6 Zoho mFILTER qmail
     |];
 }
 
@@ -95,7 +87,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2017-2021,2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2017-2021,2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
