@@ -114,7 +114,7 @@ sub field {
 
     state $subtypeset = {"addr" => "RFC822", "cdoe" => "SMTP", "host" => "DNS"};
     state $actionlist = ["failed", "delayed", "delivered", "relayed", "expanded"];
-    state $correction = {'deliverable' => 'delivered', 'expired' => 'delayed', 'failure' => 'failed'};
+    state $correction = {'deliverable' => 'delivered', 'expired' => 'failed', 'failure' => 'failed'};
     state $fieldgroup = {
         'original-recipient'    => 'addr',
         'final-recipient'       => 'addr',
