@@ -12,13 +12,12 @@ sub match {
     #                           1: Matched
     # @since v4.0.0
     my $class = shift;
-    my $argv1 = shift // return undef;
+    my $argv1 = shift // return 0;
 
     # Destination mail server does not accept any message
     state $index = [
-        'does not accept mail (nullmx)',
+        'does not accept mail',             # Sendmail
         'host/domain does not accept mail', # iCloud
-        'host does not accept mail',        # Sendmail
         'mail receiving disabled',
         'name server: .: host not found',   # Sendmail
         'no mx record found for domain=',   # Oath(Yahoo!)
@@ -37,12 +36,10 @@ sub true {
     # @since v4.0.0
     # @see http://www.ietf.org/rfc/rfc2822.txt
     my $class = shift;
-    my $argvs = shift // return undef;
-    my $reply = int $argvs->{'replycode'} || 0;
-    return 1 if $argvs->{'reason'} eq 'notaccept';
+    my $argvs = shift // return 0; my $reply = int $argvs->{'replycode'} || 0;
 
     # SMTP Reply Code is 521, 554 or 556
-    return 1 if $reply == 521 || $reply == 554 || $reply == 556;
+    return 1 if $argvs->{'reason'} eq 'notaccept' || $reply == 521 || $reply == 556;
     return 0 if $argvs->{'command'} ne 'MAIL';
     return __PACKAGE__->match(lc $argvs->{'diagnosticcode'});
 }
@@ -96,7 +93,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018,2020-2023,2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018,2020-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
