@@ -3,14 +3,16 @@ use v5.26;
 use strict;
 use warnings;
 
-sub get {
+sub find {
     # Detect bounce reason from https://cox.com/
     # @param    [Sisimai::Fact] argvs   Decoded email object
     # @return   [String]                The bounce reason at Cox
-    # @see      https://www.cox.com/residential/support/email-error-codes.html
+    # @see
+    # - Email Error Codes: https://www.cox.com/business/support/email-error-codes.html
+    # - Feedback Loop Service https://www.cox.com/business/support/feedback-loop-service.html
     # @since v4.25.8
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argvs = shift // return ""; return "" unless $argvs->{'diagnosticcode'};
 
     state $errorcodes = {
         # CXBL
@@ -68,7 +70,7 @@ sub get {
         'IPBL0101'  => 'blocked',       # The sending IP is in the Spamhaus Zen and Invaluement ivmSIP DNSBLs.
         'IPBL0110'  => 'blocked',       # The sending IP is in the Return Path and Invaluement ivmSIP DNSBLs.
         'IPBL0111'  => 'blocked',       # The sending IP is in the Spamhaus Zen, Return Path and Invaluement ivmSIP DNSBLs.
-        'IPBL1000'  => 'blocked',       # The sending IP address is listed on a CSI blacklist. You can check your status on the CSI website.
+        'IPBL1000'  => 'blocked',       # The sending IP address is listed on a CSI blacklist. 
         'IPBL1001'  => 'blocked',       # The sending IP is listed in the Cloudmark CSI and Spamhaus Zen DNSBLs.
         'IPBL1010'  => 'blocked',       # The sending IP is listed in the Cloudmark CSI and Return Path DNSBLs.
         'IPBL1011'  => 'blocked',       # The sending IP is in the Cloudmark CSI, Spamhaus Zen and Return Path DNSBLs.
@@ -76,12 +78,12 @@ sub get {
         'IPBL1101'  => 'blocked',       # The sending IP is in the Cloudmark CSI, Spamhaus Zen and Invaluement IVMsip DNSBLs.
         'IPBL1110'  => 'blocked',       # The sending IP is in the Cloudmark CSI, Return Path and Invaluement ivmSIP DNSBLs.
         'IPBL1111'  => 'blocked',       # The sending IP is in the Cloudmark CSI, Spamhaus Zen, Return Path and Invaluement ivmSIP DNSBLs.
-        'IPBL00001' => 'blocked',       # The sending IP address is listed on a Spamhaus blacklist. Check your status at Spamhaus.
+        'IPBL00001' => 'blocked',       # The sending IP address is listed on a Spamhaus blacklist.
 
         'URLBL011'  => 'spamdetected',  # A URL within the body of the message was found on blocklists SURBL and Spamhaus DBL.
         'URLBL101'  => 'spamdetected',  # A URL within the body of the message was found on blocklists SURBL and ivmURI.
         'URLBL110'  => 'spamdetected',  # A URL within the body of the message was found on blocklists Spamhaus DBL and ivmURI.
-        'URLBL1001' => 'spamdetected',  # The URL is listed on a Spamhaus blacklist. Check your status at Spamhaus.
+        'URLBL1001' => 'spamdetected',  # The URL is listed on a Spamhaus blacklist.
     };
     state $messagesof = {
         'blocked' => [
@@ -121,6 +123,8 @@ sub get {
             # - The SMTP connection has exceeded the 100 email message threshold and was disconnected.
             # - The sending IP address has exceeded one of these rate limits and has been temporarily
             #   blocked.
+            # - Cox enforces various rate limits to protect our platform. The sending IP address
+            #   has exceeded one of these rate limits and has been temporarily blocked.
             'too many sessions from',
             'requested action aborted: try again later',
             'message threshold exceeded',
@@ -137,14 +141,11 @@ sub get {
     unless( $reasontext ) {
         # The error code was not found in $errorcodes
         $issuedcode = lc $issuedcode;
-        REASON: for my $e ( keys %$messagesof ) {
+        for my $e ( keys %$messagesof ) {
             # Try to find with each error message defined in $messagesof
-            for my $f ( $messagesof->{ $e }->@* ) {
-                # Find an error reason
-                next unless index($issuedcode, $f) > -1;
-                $reasontext = $e;
-                last REASON;
-            }
+            next unless grep { index($issuedcode, $_) > -1 } $messagesof->{ $e }->@*;
+            $reasontext = $e;
+            last;
         }
     }
     return $reasontext;
@@ -166,14 +167,14 @@ Sisimai::Rhost::Cox - Detect the bounce reason returned from Cox
 =head1 DESCRIPTION
 
 C<Sisimai::Rhost::Cox> detects the bounce reason from the content of C<Sisimai::Fact> object as an
-argument of C<get()> method when the value of C<rhost> or C<destination> of the object is C<cox.net>.
+argument of C<find()> method when the value of C<rhost> or C<destination> of the object is C<cox.net>.
 This class is called only C<Sisimai::Fact> class.
 
 =head1 CLASS METHODS
 
-=head2 C<B<get(I<Sisimai::Fact Object>)>>
+=head2 C<B<find(I<Sisimai::Fact Object>)>>
 
-C<get()> method detects the bounce reason.
+C<find()> method detects the bounce reason.
 
 =head1 AUTHOR
 
@@ -181,7 +182,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2020-2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2020-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
