@@ -11,7 +11,7 @@ sub find {
     # @see      https://ca.godaddy.com/help/fix-rejected-email-with-a-bounce-error-40685
     # @since v4.22.2
     my $class = shift;
-    my $argvs = shift // return undef; return "" unless $argvs->{'diagnosticcode'};
+    my $argvs = shift // return ""; return "" unless $argvs->{'diagnosticcode'};
 
     state $errorcodes = {
         # Sender bounces
@@ -195,6 +195,15 @@ sub find {
             #   other. They need to correct their forwarding settings.
             'message is looping',
         ],
+        'toomanyconn' => [
+            # - 550 5.7.232 Your message can't be sent because your trial tenant has exceeded
+            #   its daily limit for sending email to external recipients (tenant external
+            #   recipient rate limit)
+            # - 550 5.7.233 - Your message can't be sent because your tenant exceeded its daily
+            #   limit for sending email to external recipients (tenant external recipient rate
+            #   limit)
+            "exceeded its daily limit",
+        ],
         'userunknown' => [
             # - 550 Recipient not found
             # - The recipient is not a valid email address.
@@ -218,12 +227,10 @@ sub find {
 
     $issuedcode = lc $issuedcode;
     for my $e ( keys %$messagesof ) {
-        for my $f ( $messagesof->{ $e }->@* ) {
-            next if index($issuedcode, $f) == -1;
-            $reasontext = $e;
-            last
-        }
-        last if $reasontext;
+        # Try to find the error message matches with the given error message string
+        next unless grep { index($issuedcode, $_) > -1 } $messagesof->{ $e }->@*;
+        $reasontext = $e;
+        last;
     }
     return $reasontext;
 }
@@ -259,7 +266,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2017-2018,2020-2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2017-2018,2020-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
