@@ -226,9 +226,9 @@ sub find {
             # - A valid X.509 certificate that isn't expired must be presented. X.509 certificates
             #   must be renewed after their expiration, commonly annually.
             ['5.7.51',  0, 0, 'restrictdomainstoipaddresses or restrictdomainstocertificate'],
-            ['4.7.321', 0, 0, 'starttls-not-supported: destination mail server must support tls to receive mail'],
-            ['5.7.321', 0, 0, 'starttls-not-supported: destination mail server must support tls to receive mail'],
-            ['5.7.322', 0, 0, "certificate-expired: destination mail server's certificate is expired"],
+            ['4.7.321', 0, 0, 'starttls-not-supported:'],
+            ['5.7.321', 0, 0, 'starttls-not-supported:'],
+            ['5.7.322', 0, 0, "certificate-expired:"],
 
             # - Records are DNSSEC authentic, but one or multiple of these scenarios occurred:
             #   - The destination mail server's certificate doesn't match with what is expected per
@@ -240,13 +240,13 @@ sub find {
             #   validity of recipient address and determine if the destination server is configured
             #   correctly to receive messages. 
             # - For more information about DANE, see: https://datatracker.ietf.org/doc/html/rfc7671
-            ['4.7.323', 0, 0, 'tlsa-invalid: The domain failed dane validation'],
-            ['5.7.323', 0, 0, 'tlsa-invalid: The domain failed dane validation'],
+            ['4.7.323', 0, 0, 'tlsa-invalid:'],
+            ['5.7.323', 0, 0, 'tlsa-invalid:'],
 
             # - The destination domain indicated it was DNSSEC-authentic, but Exchange Online was 
             #   not able to verify it as DNSSEC-authentic.
-            ['4.7.324', 0, 0, 'dnssec-invalid: destination domain returned invalid dnssec records'],
-            ['5.7.324', 0, 0, 'dnssec-invalid: destination domain returned invalid dnssec records'],
+            ['4.7.324', 0, 0, 'dnssec-invalid:'],
+            ['5.7.324', 0, 0, 'dnssec-invalid:'],
 
             # - This happens when the presented certificate identities (CN and SAN) of a destina-
             #   tion SMTP target host don't match any of the domains or MX host.
@@ -254,8 +254,8 @@ sub find {
             #   validity of recipient address and determine if the destination server is configured
             #   correctly to receive messages. For more information, see How SMTP DNS-based Authen-
             #   tication of Named Entities (DANE) works to secure email communications.
-            ['4.7.325', 0, 0, 'certificate-host-mismatch: remote certificate must have a common name or subject alternative name matching the hostname (dane)'],
-            ['5.7.325', 0, 0, 'certificate-host-mismatch: remote certificate must have a common name or subject alternative name matching the hostname (dane)'],
+            ['4.7.325', 0, 0, 'certificate-host-mismatch:'],
+            ['5.7.325', 0, 0, 'certificate-host-mismatch:'],
         ],
         'mailboxfull' => [
             # Exchange Server 2019 ----------------------------------------------------------------
@@ -527,7 +527,7 @@ sub find {
             # - The sender has exceeded the recipient rate limit as described in Sending limits.
             # - This could indicate the account has been compromised and is being used to send
             #   spam.
-            ['5.1.90', 0, 0, "your message can't be sent because you've reached your daily limit for message recipients"],
+            ['5.1.90', 0, 0, "reached your daily limit for message recipients"],
 
             # - The sender has exceeded the recipient rate limit or the message rate limit as de-
             #   scribed in Sending limits.
@@ -542,7 +542,7 @@ sub find {
             #   Microsoft 365 or Office 365 users from rapidly filling their inboxes with a large
             #   number of messages from errant automated notification systems or other single-send-
             #   er mail storms.
-            ['5.2.121', 0, 0, "recipient's per hour message receive limit from specific sender exceeded"],
+            ['5.2.121', 0, 0, "recipient's per hour message receive limit"],
 
             # - The Microsoft 365 or Office 365 recipient has exceeded the number of messages they
             #   can receive per hour from all senders.
@@ -550,7 +550,7 @@ sub find {
             #   messages they send per hour to a specific recipient. This limit helps protect
             #   Microsoft 365 and Office 365 users from rapidly filling their inboxes with a large
             #   number of messages from errant automated notification systems or other mail storms.
-            ['5.2.122', 0, 0, "recipient's per hour message receive limit exceeded"],
+            ['5.2.122', 0, 0, "recipient's per hour message receive limit"],
 
             # - Access denied, [$SenderIPAddress] has exceeded permitted limits within $range range
             # - The sender's IPv6 range has attempted to send too many messages in too short a time
@@ -562,8 +562,8 @@ sub find {
             # - Ensure that any compromises or open relays have been resolved, and then contact
             #   support through your regular channel. For more information, see Fix email delivery
             #   issues for error codes 5.7.700 through 5.7.750 in Exchange Online.
-            ['5.7.', 700, 749, 'access denied, tenant has exceeded threshold'],
-            ['5.7.', 700, 749, 'access denied, traffic not accepted from this ip'],
+            ['5.7.', 700, 749, 'tenant has exceeded threshold'],
+            ['5.7.', 700, 749, 'traffic not accepted from this ip'],
         ],
         'suspend' => [
             # Exchange Online ---------------------------------------------------------------------
@@ -621,7 +621,7 @@ sub find {
             #   is disabled. For this scenario to work, the organization's Office 365 administrator
             #   should either enable Journaling Archive or change the journaling rule to journal
             #   messages to a different location.
-            ['5.3.190', 0, 0, 'journaling on-premises messages to microsoft 365 or office 365 not supported when journaling archive is disabled'],
+            ['5.3.190', 0, 0, 'when journaling archive is disabled'],
 
             # Previous versions of Exchange Server ------------------------------------------------
             ['5.0.0',  0, 0, 'helo / ehlo requires domain address'],
@@ -757,13 +757,61 @@ sub find {
             ['5.1.351', 0, 0, 'remote server returned unknown recipient or mailbox unavailable'],
         ],
     };
+    state $errorcodes = {
+        #  The mail server IP connecting to Outlook.com server has exceeded the rate limit allowed.
+        #  Reason for rate limitation is related to IP/domain reputation.
+        "RP-001" => ["421", "badreputation"],
+
+        #  The mail server IP connecting to Outlook.com server has exceeded the rate limit allowed
+        #  on this connection. Reason for rate limitation is related to IP/domain reputation.
+        "RP-002" => ["421", "badreputation"],
+
+        #  The mail server IP connecting to Outlook.com server has exceeded the connection limit
+        #  allowed. Reason for limitation is related to IP/domain reputation.
+        "RP-003" => ["421", "badreputation"],
+
+        #  Mail rejected by Outlook.com for policy reasons. Reasons for rejection may be related
+        #  to content with spam-like characteristics or IP/domain reputation. 
+        "SC-001" => ["550", "badreputation"],
+
+        #  Mail rejected by Outlook.com for policy reasons. The mail server IP connecting to
+        #  Outlook.com has exhibited namespace mining behavior.
+        "SC-002" => ["550", "policyviolation"],
+
+        #  Mail rejected by Outlook.com for policy reasons. Your IP address appears to be an
+        #  open proxy/relay.
+        "SC-003" => ["550", "blocked"],
+
+        #  Mail rejected by Outlook.com for policy reasons. A block has been placed against your
+        #  IP address because we have received complaints concerning mail coming from that IP
+        #  address. We recommend enrolling in our Junk Email Reporting Program (JMRP), a free
+        #  program intended to help senders remove unwanted recipients from their email list
+        "SC-004" => ["550", "blocked"],
+
+        #  Mail rejected by Outlook.com for policy reasons. We generally do not accept email
+        #  from dynamic IP's as they are not typically used to deliver unauthenticated SMTP email
+        #  to an Internet mail server. (Spamhaus)
+        "DY-001" => ["550", "blocked"],
+
+        #  Mail rejected by Outlook.com for policy reasons. The likely cause is a compromised or
+        #  virus infected server/personal computer.
+        "DY-002" => ["550", "virusdetected"],
+
+        #  Mail rejected by Outlook.com for policy reasons. If you are not an email/network admin
+        #  please contact your Email/Internet Service Provider for help. For more information
+        #  about this block and to request removal please go to: Spamhaus.
+        "OU-001" => ["550", "blocked"],
+
+        #  Mail rejected by Outlook.com for policy reasons. Reasons for rejection may be related
+        #  to content with spam-like characteristics or IP/domain reputation.
+        "OU-002" => ["550", "badreputation"],
+    };
 
     my $statuscode = $argvs->{'deliverystatus'};
     my $thirddigit = int [split /[.]/, $statuscode]->[-1];
     my $issuedcode = lc $argvs->{'diagnosticcode'};
-    my $reasontext = '';
 
-    REASON: for my $e ( keys %$messagesof ) {
+    for my $e ( keys %$messagesof ) {
         # Each key is a reason name
         for my $f ( $messagesof->{ $e }->@* ) {
             # ["status-code", min, max, "error message"]
@@ -777,13 +825,16 @@ sub find {
                 next if $thirddigit < $f->[1]; 
                 next if $thirddigit > $f->[2]; 
             }
-
-            next unless index($issuedcode, $f->[3]) > -1;
-            $reasontext = $e;
-            last REASON;
+            return $e if index($issuedcode, $f->[3]) > -1;
         }
     }
-    return $reasontext;
+    for my $e ( keys %$errorcodes ) {
+        # The key name is an error code described at Outlook.com Postmaster/Troubleshooting
+        # https://substrate.office.com/ip-domain-management-snds/postmaster/troubleshooting
+        next if index($argvs->{'diagnosticcode'}, $e) < 0;
+        return $errorcodes->{ $e }->[1] if $argvs->{'replycode'} eq $errorcodes->{ $e }->[0];
+    }
+    return "";
 }
 
 1;
